#
# spec file for package postfixadmin
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2007-2018 Christian Boltz
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           postfixadmin
Version:        3.3.13
Release:        1%{?dist}
Url:            http://postfixadmin.sourceforge.net/
Source0:        %{name}-%{name}-%{version}.tar.gz
Source1:        config.local.php
Source2:        apache-postfixadmin.conf
Patch1000:	postfixadmin-3.3.8.password_encryption.diff
Patch1001:	postfixadmin-3.3.8.usersdisable.patch
Patch1002:	postfixadmin-3.3.8.footer.patch
Patch1003:	postfixadmin-3.3.10_2.showpass.diff
Patch1004:	postfixadmin-3.3.10_2.weblink.diff

BuildArch:      noarch

# Web interface
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_ver}
  # Requires:   mod_php_any # no idea in which fedora package mod_php5 is...
Requires:       php_database
%else
Requires:       mod_php_any
Requires:       php_any_db
Recommends:     php-mysql
%endif

Requires:       /usr/sbin/sendmail
Requires:       php-mbstring
Requires:       php-spl

# test/*, xmlrpc.php, squirrelmail plugin
# big dependency, not needed by all users - therefore no hard Requirement
%if 0%{?suse_version}
Recommends:     php5-ZendFramework < 2.0
%endif

# vacation.pl
Requires:       perl(DBI)
Requires:       perl(Email::Sender::Simple)
Requires:       perl(Email::Sender::Transport::SMTP)
Requires:       perl(Email::Simple)
Requires:       perl(Email::Simple::Creator)
Requires:       perl(Email::Valid)
Requires:       perl(Encode)
Requires:       perl(File::Basename)
Requires:       perl(Getopt::Std)
Requires:       perl(Log::Log4perl)
Requires:       perl(MIME::EncWords)
Requires:       perl(Try::Tiny)
Requires:       perl(strict)

# cleanupdirs.pl
Requires:       perl(File::Path)
Requires:       perl(Getopt::Long)
# mkeveryone.pl
Requires:       perl(Fcntl)
Requires:       perl(IO)
Requires:       perl(IO::File)
Requires:       perl(POSIX)
Requires:       perl(Time::Local)
# fetchmail.pl
Requires:       perl(File::Temp)
Requires:       perl(LockFile::Simple)
Requires:       perl(Sys::Syslog)

%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_ver}
# create vacation user/group
Requires(pre,preun):         shadow-utils
%define apache_group apache
%else
# create vacation user/group
PreReq:         pwdutils
%define apache_group www
Recommends:     postfix
Suggests:       php-pgsql
%endif

%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_ver}
# Do not check any files in ADDITIONS for Requires, see https://fedoraproject.org/wiki/Packaging:AutoProvidesAndRequiresFiltering
%global __requires_exclude_from ^%{_prefix}/lib/%{name}/ADDITIONS/.*$
%endif

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Summary:        Web-based management tool for Postfix virtual domains, mailboxes and aliases
License:        GPL-2.0+
Group:          Productivity/Networking/Web/Frontends

%description
PostfixAdmin is a PHP based application that handles Postfix Style Virtual Domains and
Users that are stored in MySQL or PostgreSQL.

Postfix Admin supports:
- Virtual Mailboxes / Virtual Aliases / Forwarders
- Alias domains (Domain to Domain forwarding with recipient validation)
- Vacation (auto-response) for Virtual Mailboxes.
- Quota / Alias & Mailbox limits per domain.
- Fetchmail integration
- Packaged with over 25 languages.

%prep
%setup -q -n %{name}-%{name}-%{version}
%patch1000 -p1
%patch1001 -p1
%patch1002 -p1
%patch1003 -p1
%patch1004 -p1

sed -i -e '1s|#!/usr/bin/env python$|#!/usr/bin/env python3|' \
    ADDITIONS/import_users_from_csv.py

%build

%install
mkdir -p -m0755 %{buildroot}%{_sysconfdir}/%{name}
#mkdir -p -m0755 %{buildroot}%{_datadir}/%{name}
mkdir -p -m0755 %{buildroot}%{_localstatedir}/spool/vacation
mkdir -p -m0755 %{buildroot}/%{_prefix}/lib/%{name}

mv VIRTUAL_VACATION/vacation.pl %{buildroot}%{_prefix}/lib/%{name}/
# compatibility symlink to match documentation
( cd %{buildroot}%{_localstatedir}/spool/vacation/ && ln -s ../../../usr/lib/%{name}/vacation.pl )

# copy over the code
mkdir -p -m0755 %{buildroot}/usr/share/%{name}/
install -m 0644 *.php composer.* %{buildroot}/usr/share/%{name}/
mv %{buildroot}/usr/share/%{name}/config.inc.php %{buildroot}/etc/%{name}/
install -m 0644 %{S:1} %{buildroot}/etc/%{name}/config.local.php
for d in configs languages lib model public scripts templates ; do # not copied here: ADDITIONS/ debian/ DOCUMENTS/ tests/ VIRTUAL_VACATION/
    cp -rp $d %{buildroot}/usr/share/%{name}/
done

chmod 755 %{buildroot}/usr/share/%{name}/scripts/postfixadmin-cli
install -d %{buildroot}/usr/bin
( cd %{buildroot}/usr/bin && ln -s /usr/share/%{name}/scripts/postfixadmin-cli . )

install -d %{buildroot}/var/cache/%{name}/templates_c
install -d %{buildroot}/var/cache/%{name}/sessions

# create config.local.php and templates_c symlinks
( cd %{buildroot}/usr/share/%{name} && ln -s /etc/postfixadmin/config.inc.php . )
( cd %{buildroot}/usr/share/%{name} && ln -s /etc/postfixadmin/config.local.php . )
( cd %{buildroot}/usr/share/%{name} && ln -s /var/cache/%{name}/templates_c . )

# remove files related to debian packaging (to avoid it's copied as %doc)
rm -r ADDITIONS/squirrelmail-plugin/debian/
cp -rp ADDITIONS %{buildroot}%{_prefix}/lib//%{name}/
chmod 755 %{buildroot}%{_prefix}/lib/%{name}/ADDITIONS/*.{pl,sh,py} %{buildroot}%{_prefix}/lib/%{name}/ADDITIONS/squirrelmail-plugin/locale/build.sh

# install the apache config file
mkdir -p %{buildroot}%{_sysconfdir}/httpd/conf.d
install -m 0644 %{S:2} %{buildroot}/etc/httpd/conf.d/%{name}.conf

%pre
%{_sbindir}/groupadd -r vacation 2> /dev/null || :
%{_sbindir}/useradd -c "Virtual Vacation" -d %{_localstatedir}/spool/vacation -s /sbin/nologin -M -r -g vacation vacation 2> /dev/null || :
# fix group for vacation user (if created by older versions (< 2012-02-13) of this package, it was created with group users)
%{_sbindir}/usermod -g vacation vacation 2> /dev/null || :

#if [ -z "`grep vacation /etc/postfix/master.cf 2>/dev/null`" ]; then
#cat <<'EOF' >>/etc/postfix/master.cf
## Postfix Admin Vacation
#vacation	unix	-	n	n	-	-	pipe
#	flags=Rq user=vacation argv=/usr/lib/postfixadmin/vacation.pl -f ${sender} -- ${recipient}
#EOF
#fi

%post
# PostfixAdmin 3.2 comes with a new directory layout - warn if config files are found at the old location
# (no automated migration)
if test -f /srv/www/htdocs/postfixadmin/config.inc.php ; then
    echo 'WARNING: /srv/www/htdocs/postfixadmin/config.inc.php found, please migrate your changes to /etc/postfixadmin/config.local.php' >&2
    echo 'WARNING: /srv/www/htdocs/postfixadmin/config.inc.php will be ignored!' >&2
fi
if test -f /srv/www/htdocs/postfixadmin/config.local.php ; then
    echo 'WARNING: /srv/www/htdocs/postfixadmin/config.local.php found, please migrate it to /etc/postfixadmin/config.local.php' >&2
    echo 'WARNING: /srv/www/htdocs/postfixadmin/config.local.php will be ignored!' >&2
fi

%files
%defattr(-,root,root)
%config %dir %{_sysconfdir}/%{name}
%attr(640,root,%{apache_group}) %config %{_sysconfdir}/%{name}/config.inc.php
%attr(640,root,%{apache_group}) %config(noreplace) %{_sysconfdir}/%{name}/config.local.php
%config %dir %{_sysconfdir}/httpd
%config %dir %{_sysconfdir}/httpd/conf.d
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}.conf
%doc DOCUMENTS/* *.TXT README.md VIRTUAL_VACATION
/usr/bin/postfixadmin-cli
/usr/share/%{name}/
%attr(770,root,%{apache_group}) %dir /var/cache/%{name}/
%attr(770,root,%{apache_group}) %dir /var/cache/%{name}/templates_c/
%attr(770,root,%{apache_group}) %dir /var/cache/%{name}/sessions/
%dir %{_prefix}/lib/%{name}/
%{_prefix}/lib/%{name}/ADDITIONS/
%attr( 750,root,vacation)       %{_prefix}/lib/%{name}/vacation.pl
%attr(1770,root,vacation) %dir %{_localstatedir}/spool/vacation
%{_localstatedir}/spool/vacation/vacation.pl

%changelog
* Wed May  2 2018 suse-beta@cboltz.de
- update to PostfixAdmin 3.2:
  - new directory layout (see below)
  - enable users to reset their passwords by mail or SMS
    ($CONF['forgotten_user_password_reset'],
    $CONF['forgotten_admin_password_reset'], $CONF['sms_send_function'])
  - allow local alias targets (without @domain)
  - add $CONF['edit_alias'] to disable "edit alias" function for users
  - add php_crypt $CONF["encrypt"] option
  - add support for MySQL connections over SSL
  - and more - see CHANGELOG.TXT for the full list
- move out of /srv/www/htdocs/postfixadmin - PHP code moved to
  /usr/share/postfixadmin/, smarty cache to /var/cache/postfixadmin/ and
  the config files to /etc/postfixadmin/ (no automated migration!)
- add apache config file to glue everything together. Note that the
  /postfixadmin alias is *not* enabled by default to avoid that it is
  active on all vhosts. Run "a2enflag POSTFIXADMIN" if you want that.
- adjust perl requirements for latest vacation.pl
- drop apache2-devel / httpd-devel BuildRequires - no longer needed with
  the new directory layout
- package /usr/bin/postfixadmin-cli symlink
* Sun Jun 25 2017 suse-beta@cboltz.de
- update to PostfixAdmin 3.1:
  - several broadcast improvements
  - better static DB connection cache to avoid hundreds of mysqli
    connections when doing lots of escape_string() calls
  - add favicon to fix session handling in chrome (#44)
  - various small fixes and improvements, see CHANGELOG.TXT
* Wed Feb  8 2017 suse-beta@cboltz.de
- update to PostfixAdmin 3.0.2:
  - SECURITY: don't allow to delete protected aliases (CVE-2017-5930, boo#1024211)
  - fix VacationHandler for PostgreSQL
  - AliasHandler: restrict mailbox subquery to allowed and specified domains
    to improve performance on setups with lots of mailboxes
  - allow switching between dovecot:* password schemes while still accepting
    passwords hashed using the previous dovecot:* scheme
  - FetchmailHandler: use a valid date as default for 'date'
  - fix date formatting in non-english languages when using PostgreSQL
  - various small fixes
* Sun Sep 11 2016 suse-beta@cboltz.de
- update to PostfixAdmin 3.0:
  - add sqlite backend option
  - add configurable smtp helo (CONF["smtp_client"])
  - new translation: ro (Romanian)
  - language update: tw, cs, de
  - fix escaping in gen_show_status() (could be used to DOS list-virtual by
    creating a mail address with special chars)
  - add CSRF protection for POST requests
  - list.tpl: base edit/editactive/delete links in list.tpl on $RAW_item to
    avoid double escaping, and fix some corner cases
  - fix db_quota_text() for postgresql (concat() vs. ||)
  - change default date for 'created' and 'updated' columns from 0000-00-00
    (which causes problems with MySQL strict mode) to 2000-01-01
  - allow punicode even in TLDs
  - update Smarty to 3.1.29
  - add checks to login.php and cli to ensure database layout is up to date
  - whitelist '-1' as valid value for postfixadmin-cli
  - don't stripslashes() the password in pacrypt
  - various small bugfixes
- drop patch postfixadmin-upstream-fixes-r1802-1817.diff (upstream)
- add Requires: perl(Encode), needed by vacation.pl
* Wed Oct  7 2015 opensuse@cboltz.de
- add postfixadmin-upstream-fixes-r1802-1817.diff:
  fix escaping in gen_show_status() and double escaping in list.php
  (http://sourceforge.net/p/postfixadmin/bugs/356/)
* Wed Sep 30 2015 opensuse@cboltz.de
- several fixes for the Fedora and CentOS build:
  - don't scan scripts in the ADDITIONS directory to avoid adding excessive
    dependencies
  - use centos_ver instead of centos_version (which isn't available in CentOS 7)
  - change docroot to /var/www/html
  - change apache group to "apache"
* Sat Sep 26 2015 opensuse@cboltz.de
- update to PostfixAdmin 2.93 aka 3.0 beta3
  - add list.php for list view (replaces list-*.php and fixes some
    bugs they included)
  - add FetchmailHandler (replaces fetchmail.php)
  - several bugfixes and small improvements
  - see CHANGELOG.TXT for all details
* Tue Oct 28 2014 opensuse@cboltz.de
- update to PostfixAdmin 2.92 aka 3.0 beta2
  - remove upstream postfixadmin-svn.diff and postfixadmin-svn2.diff
  - additional changes over the two patches: the version number ;-)
* Mon Oct 27 2014 opensuse@cboltz.de
- add postfixadmin-svn2.diff with changes from upstream SVN (r1705):
  - add workaround for MariaDB to fix deleting aliases (bug#325)
  - $CONF[default_aliases] can now use the new domain as alias target (patch#124)
  - check that vacation start/end date are not in the past (patch#122)
  - update vacation INSTALL.TXT with more secure locations
  - update Smarty to 3.1.21
- make dependency on Zend Framework versioned - PostfixAdmin needs 1.x
  (2.x is totally different and incompatible)
* Fri Sep 12 2014 opensuse@cboltz.de
- add postfixadmin-svn.diff with changes from upstream SVN (r1689):
  - AliasHandler: don't clean goto field when making alias inactive (bug#316)
  - list-virtual: display quota even if $CONF[used_quotas] == NO (bug#307)
  - vacation.pl: fix postgresql queries in vacation.pl (bug#315)
  - fix query in AliasHandler getList which caused an empty list on some
    systems (bug#313)
  - fetchmail.pl: fix ssl extra options (cert check, cert path, fingerprint)
  - fix logging (run setup.php to fix old log entries) (bug#317)
  - fetchmail.php: change error_reporting() to exclude E_NOTICE (bug#322)
  - fr.lang translation update (patch#123)
- make postfixadmin-cli executable
* Tue May  6 2014 opensuse@cboltz.de
- update to PostfixAdmin 2.91 aka 3.0 beta1
  - new commandline client postfixadmin-cli
  - vacation start and end date
  - (nearly) complete rewrite to *Handler classes
  - smarty templates
  - and much more, see upstream CHANGELOG.TXT
* Thu Feb 20 2014 opensuse@cboltz.de
- update to PostfixAdmin 2.3.7 (bugfix release)
  changes that were not included in the package yet:
  - SECURITY: fix SQL injection in show_gen_status() (CVE-2014-2655, bnc#870434)
  - don't trim() mail address to avoid that aliases starting with a space are
    allowed. This fixes http://sourceforge.net/p/postfixadmin/bugs/210/ and
    https://sourceforge.net/p/postfixadmin/feature-requests/113/
  - update regex in check_domain() to support new, longer TLDs like .international
  - vacation.pl: encode subject
  - vacation.pl: disable use of TLS by default due to a bug in Mail::Sender 0.8.22
    (you can re-enable it with $smtp_tls_allowed)
- remove postfixadmin-2.3-branch.diff
* Sat Sep 28 2013 chris@computersalat.de
- rework pre section
  * if useradd -r then groupadd -r, too
* Thu Sep 12 2013 opensuse@cboltz.de
- add postfixadmin-2.3-branch.diff with all changes between 2.3.6 release
  and SVN r1521:
  - lt.lang, da.lang translation update
  - when enabling/disabling a mailbox, also update the corresponding alias
  - fix creating superadmin in setup.php with MariaDB (more strict SQL)
  - trim() localpart in create-mailbox to avoid mailbox names with leading space
  - mark vacation_notification.notified field as latin1 to avoid overlong index
* Wed Jan  2 2013 opensuse@cboltz.de
- update to PostfixAdmin 2.3.6 (bugfix release)
  changes that were not included in the package yet:
  - fix double inclusion of config.inc.php in setup.php
  - fix bool and date handling in fetchmail
- remove upstreamed patches
* Fri Nov 30 2012 opensuse@cboltz.de
- more cross-distributin %%if: pwdutils, php_any_db
* Mon Nov 26 2012 Ralf Lang <lang@b1-systems.de>
- require php-mbstring as setup.php reports this as a hard dependency
* Thu Jun 28 2012 opensuse@cboltz.de
- fix footer link (upstream r1402)
- focus username field in login form (upstream r1404)
- change existing vacation user (< 2012-02-13) to group vacation
* Sun Jun  3 2012 opensuse@cboltz.de
- add some %%if for cross-distribution handling
* Mon Feb 13 2012 opensuse@cboltz.de
- add vacation user to the vacation group (instead of the default "users")
* Thu Feb  9 2012 opensuse@cboltz.de
- update r1342 patch to fix SLE_10 build failure
* Thu Feb  2 2012 opensuse@cboltz.de
- add patch to display domain and mailbox description with correct
  encoding (upstream r1342)
* Thu Jan 26 2012 opensuse@cboltz.de
- update to PostfixAdmin 2.3.5 (security release)
  - fixes some SQL injections (CVE-2012-0811)
  - fixes some XSS vulnerabilities (CVE-2012-0812)
  - see CHANGELOG.TXT or bnc#741455 for details
* Sun Oct 16 2011 opensuse@cboltz.de
- include a patch with fixes since the 2.3.4 release (see
  CHANGELOG.TXT for details)
- Add PreReq: pwdutils
* Fri Sep 16 2011 opensuse@cboltz.de
- 2.3.4 release (bugfix release, see CHANGELOG.TXT for details)
* Sun Aug 28 2011 opensuse@cboltz.de
- move vacation.pl and ADDITIONS to /usr/lib/postfixadmin/
* Mon Aug  1 2011 opensuse@cboltz.de
- spec cleanup (manually + spec-cleaner)
- create vacation user
- move %%changelog to .changes
* Tue Mar 15 2011 Christian Boltz <opensuse@cboltz.de>
- 2.3.3 release
  bugfix release for 2.3.2 - see CHANGELOG.TXT for details
* Tue Aug 24 2010 Christian Boltz <opensuse@cboltz.de>
- 2.3.2 release
  bugfix release for 2.3.1 - see CHANGELOG.TXT for details
* Fri Jul  9 2010 Christian Boltz <opensuse@cboltz.de>
- 2.3.1 release
  bugfix release for 2.3 - see CHANGELOG.TXT for details
* Wed Oct 28 2009 Christian Boltz <opensuse@cboltz.de>
- 2.3 release
  Most important changes:
  * Improved Aliased domains support (no longer relying on catch-all domains) -
    Note this requires Postfix configuration changes; old configuration(s) will
    continue to work.
  * Security fix for setup.php (password required to access; setup.php can
    generate this and help you)
  * Superadmin can now setup fetchmail for all users
  * Enhanced fetchmail.pl script (file locking, syslog logging, configuration
    file etc)
  * Added dovecot quota support (documentation + viewing in Postfixadmin) for
    dovecot 1.0/1.1 and >= 1.2
  * Vacation re-notification after defineable timeout (default remains to
    notify only once)
  * Refactoring of /users (see /model) and XmlRpc interface for remote mail
    clients (E.g. squirrelmail-postfixadmin)
  * Add dovecot password support (see here)
  * Added support for courier authlib authentication flavours
    ($CONF['authlib_default_flavor'])
  * update.php should handle all database updates for you
  * Lots of small updates and random new minor features
  * bug fixes ;-)
* Thu Jul 24 2008 Christian Boltz <opensuse@cboltz.de>
- updated to 2.2.1.1 (fixed version number displayed in the footer)
* Tue Jul 22 2008 Christian Boltz <opensuse@cboltz.de>
- updated to 2.2.1 (fixes several bugs, no new features)
* Sun Jun  8 2008 Christian Boltz <opensuse@cboltz.de>
- finally created a package for the 2.2.0 release
* Fri Feb 29 2008 Christian Boltz <opensuse@cboltz.de>
- updated spec to follow the *.css move to css/
* Sun Dec  2 2007 Christian Boltz <opensuse@cboltz.de>
- updated to SVN version
- commented out several sections
- auto-detect serverroot and install PHP files etc. there
* Fri Dec 15 2006 lfarkas@lfarkas.org
- initial build
